@@ -3,7 +3,8 @@ import os
 
 class AdaApiConfig:
     AUTH_HOST = os.environ.get('AUTH_API_HOST', "https://adalytica.io/user-identity/auth")
-    HOST = os.environ.get('ADA_API_HOST', "http://adalytica.io")
+    HOST_KEYWORD = os.environ.get('ADA_API_KEYWORD_HOST', "http://adalytica.io/keyword")
+    HOST_TOPIC = os.environ.get('ADA_API_TOPIC_HOST', "http://adalytica.io/topic")
     PORT = os.environ.get('ADA_API_PORT', "80")
     USERNAME = os.environ.get('ADA_API_USERNAME', "")
     PASSWORD = os.environ.get('ADA_API_PASSWORD', "")
